@@ -15,7 +15,7 @@ Assamese_LO_Latest_full
    <be>Assamese Language Meta-Package for LibreOffice</be>
    <bg>Assamese Language Meta-Package for LibreOffice</bg>
    <bn>Assamese Language Meta-Package for LibreOffice</bn>
-   <ca>Metapaquet d'idioma Assamesa per LibreOffice</ca>
+   <ca>Metapaquet d'idioma Assamès per LibreOffice</ca>
    <cs>Assamese Language Meta-Package for LibreOffice</cs>
    <da>Assamese Language Meta-Package for LibreOffice</da>
    <de>Assamisches Meta-Paket für LibreOffice</de>
@@ -28,7 +28,7 @@ Assamese_LO_Latest_full
    <fa>Assamese Language Meta-Package for LibreOffice</fa>
    <fil_PH>Assamese Language Meta-Package for LibreOffice</fil_PH>
    <fi>Assamilainen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Assamese Language Meta-Package for LibreOffice</fr_BE>
+   <fr_BE>Méta-Paquet en langue assamaise pour LibreOffice</fr_BE>
    <fr>Méta-Paquet en langue assamaise pour LibreOffice</fr>
    <gl_ES>Asamés Meta-paquete de Idioma para LibreOffice</gl_ES>
    <gu>Assamese Language Meta-Package for LibreOffice</gu>
@@ -42,6 +42,7 @@ Assamese_LO_Latest_full
    <ja>LibreOffice用のアッサム語メタパッケージ</ja>
    <kk>Assamese Language Meta-Package for LibreOffice</kk>
    <ko>Assamese Language Meta-Package for LibreOffice</ko>
+   <ku>Assamese Language Meta-Package for LibreOffice</ku>
    <lt>Assamese Language Meta-Package for LibreOffice</lt>
    <mk>Assamese Language Meta-Package for LibreOffice</mk>
    <mr>Assamese Language Meta-Package for LibreOffice</mr>
@@ -49,6 +50,7 @@ Assamese_LO_Latest_full
    <nb>Assamesisk språkpakke for LibreOffice</nb>
    <nl_BE>Assamese Language Meta-Package for LibreOffice</nl_BE>
    <nl>Assamese Taal Meta-Pakket voor LibreOffice​</nl>
+   <or>Assamese Language Meta-Package for LibreOffice</or>
    <pl>Meta-pakiet języka Assamese dla LibreOffice</pl>
    <pt_BR>Assamês Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Assamês Meta-Pacote de Idioma para LibreOffice</pt>
@@ -56,7 +58,8 @@ Assamese_LO_Latest_full
    <ru>Assamese Language Meta-Package for LibreOffice</ru>
    <sk>Assamese Language Meta-Package for LibreOffice</sk>
    <sl>Asameški jezikovni meta-paket za LibreOffice</sl>
-   <sq>Assamese Language Meta-Package for LibreOffice</sq>
+   <so>Assamese Language Meta-Package for LibreOffice</so>
+   <sq>Meta-Paketë gjuhësore për LibreOffice-in në asamisht</sq>
    <sr>Assamese Language Meta-Package for LibreOffice</sr>
    <sv>Assamesiskt Språk Meta-Paket för LibreOffice</sv>
    <th>Meta-Package ภาษา Asamese สำหรับ LibreOffice</th>
