@@ -31,8 +31,9 @@ Farsi_LO_Latest_full
    <fr_BE>Méta-paquet de langue farsie pour LibreOffice</fr_BE>
    <fr>Méta-paquet de langue farsie pour LibreOffice</fr>
    <gl_ES>Persa Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Farsi Language Meta-Package for LibreOffice</gu>
    <he_IL>Farsi Language Meta-Package for LibreOffice</he_IL>
-   <hi>Farsi Language Meta-Package for LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस हेतु फ़ारसी भाषा मेटा-पैकेज</hi>
    <hr>Farsi Language Meta-Package for LibreOffice</hr>
    <hu>Farsi Language Meta-Package for LibreOffice</hu>
    <id>Farsi Language Meta-Package for LibreOffice</id>
@@ -41,6 +42,7 @@ Farsi_LO_Latest_full
    <ja>LibreOffice用のペルシャ語メタパッケージ</ja>
    <kk>Farsi Language Meta-Package for LibreOffice</kk>
    <ko>Farsi Language Meta-Package for LibreOffice</ko>
+   <ku>Farsi Language Meta-Package for LibreOffice</ku>
    <lt>Farsi Language Meta-Package for LibreOffice</lt>
    <mk>Farsi Language Meta-Package for LibreOffice</mk>
    <mr>Farsi Language Meta-Package for LibreOffice</mr>
@@ -48,6 +50,7 @@ Farsi_LO_Latest_full
    <nb>Farsi språkpakke for LibreOffice</nb>
    <nl_BE>Farsi Language Meta-Package for LibreOffice</nl_BE>
    <nl>Farsisch Taal Meta-Pakket voor LibreOffice</nl>
+   <or>Farsi Language Meta-Package for LibreOffice</or>
    <pl>Meta-pakiet języka Farsi dla LibreOffice</pl>
    <pt_BR>Persa Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Persa Meta-Pacote de Idioma para LibreOffice</pt>
@@ -55,7 +58,8 @@ Farsi_LO_Latest_full
    <ru>Farsi Language Meta-Package for LibreOffice</ru>
    <sk>Farsi Language Meta-Package for LibreOffice</sk>
    <sl>Farsi jezikovni meta-paket za LibreOffice</sl>
-   <sq>Farsi Language Meta-Package for LibreOffice</sq>
+   <so>Farsi Language Meta-Package for LibreOffice</so>
+   <sq>Meta-Paketë gjuhësore për LibreOffice-in në persisht</sq>
    <sr>Farsi Language Meta-Package for LibreOffice</sr>
    <sv>Farsi Språk Meta-Paket för LibreOffice</sv>
    <th>Meta-Package ภาษา Farsi สำหรับ LibreOffice</th>
