@@ -31,8 +31,9 @@ Korean_LO_Latest_main
    <fr_BE>Localisation en coréen pour LibreOffice</fr_BE>
    <fr>Localisation en coréen pour LibreOffice</fr>
    <gl_ES>Localización do LibreOffice ao coreano</gl_ES>
+   <gu>Korean localisation of LibreOffice</gu>
    <he_IL>תרגומי LibreOffice לקוריאנית</he_IL>
-   <hi>Korean localisation of LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस का कोरियाई संस्करण</hi>
    <hr>Korean localisation of LibreOffice</hr>
    <hu>Korean localisation of LibreOffice</hu>
    <id>Korean localisation of LibreOffice</id>
@@ -41,6 +42,7 @@ Korean_LO_Latest_main
    <ja>LibreOffice の韓国（朝鮮）語版</ja>
    <kk>Korean localisation of LibreOffice</kk>
    <ko>Korean localisation of LibreOffice</ko>
+   <ku>Korean localisation of LibreOffice</ku>
    <lt>Korean localisation of LibreOffice</lt>
    <mk>Korean localisation of LibreOffice</mk>
    <mr>Korean localisation of LibreOffice</mr>
@@ -48,14 +50,16 @@ Korean_LO_Latest_main
    <nb>Koreansk lokaltilpassing av LibreOffice</nb>
    <nl_BE>Korean localisation of LibreOffice</nl_BE>
    <nl>Koreaanse lokalisatie van LibreOffice</nl>
+   <or>Korean localisation of LibreOffice</or>
    <pl>Koreańska lokalizacja LibreOffice</pl>
    <pt_BR>Coreano Localização para o LibreOffice</pt_BR>
    <pt>Coreano Localização para LibreOffice</pt>
    <ro>Korean localisation of LibreOffice</ro>
    <ru>Korean localisation of LibreOffice</ru>
    <sk>Korean localisation of LibreOffice</sk>
-   <sl>Korean localisation of LibreOffice</sl>
-   <sq>Korean localisation of LibreOffice</sq>
+   <sl>Korejske krajevne nastavitve za LibreOffice</sl>
+   <so>Korean localisation of LibreOffice</so>
+   <sq>Përkthim i LibreOffice-it në koreançe</sq>
    <sr>Korean localisation of LibreOffice</sr>
    <sv>Koreansk lokalisering av LibreOffice</sv>
    <th>Korean localisation ของ LibreOffice</th>
