@@ -31,8 +31,9 @@ Office-LibreOffice(US)_Latest_main
    <fr_BE>Meta-Paquet pour LibreOffice</fr_BE>
    <fr>Meta-Paquet pour LibreOffice</fr>
    <gl_ES>Meta-paquete para LibreOffice</gl_ES>
+   <gu>Meta-Package for LibreOffice</gu>
    <he_IL>Meta-Package for LibreOffice</he_IL>
-   <hi>Meta-Package for LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस हेतु मेटा-पैकेज</hi>
    <hr>Meta-Package for LibreOffice</hr>
    <hu>Meta-Package for LibreOffice</hu>
    <id>Meta-Package for LibreOffice</id>
@@ -41,6 +42,7 @@ Office-LibreOffice(US)_Latest_main
    <ja>LibreOffice用メタパッケージ</ja>
    <kk>Meta-Package for LibreOffice</kk>
    <ko>Meta-Package for LibreOffice</ko>
+   <ku>Meta-Package for LibreOffice</ku>
    <lt>Meta-Package for LibreOffice</lt>
    <mk>Meta-Package for LibreOffice</mk>
    <mr>Meta-Package for LibreOffice</mr>
@@ -48,14 +50,16 @@ Office-LibreOffice(US)_Latest_main
    <nb>LibreOffice metapakke</nb>
    <nl_BE>Meta-Package for LibreOffice</nl_BE>
    <nl>Meta-Pakket voor LibreOffice</nl>
+   <or>Meta-Package for LibreOffice</or>
    <pl>Meta-Pakiet dla LibreOffice</pl>
-   <pt_BR>Pacote para o LibreOffice</pt_BR>
+   <pt_BR>Meta-Pacote para o LibreOffice</pt_BR>
    <pt>Meta-Pacote para LibreOffice</pt>
    <ro>Meta-Package for LibreOffice</ro>
    <ru>Мета-пакет для LibreOffice</ru>
    <sk>Meta-Package for LibreOffice</sk>
    <sl>Meta-paket za LibreOffice</sl>
-   <sq>Meta-Package for LibreOffice</sq>
+   <so>Meta-Package for LibreOffice</so>
+   <sq>Meta-Paketë për LibreOffice</sq>
    <sr>Meta-Package for LibreOffice</sr>
    <sv>Meta-Paket för LibreOffice</sv>
    <th>Meta-Package สำหรับ LibreOffice</th>
