@@ -31,8 +31,9 @@ Slovenian_LO_full
    <fr_BE>Méta-paquet langue slovène pour LibreOffice</fr_BE>
    <fr>Méta-paquet langue slovène pour LibreOffice</fr>
    <gl_ES>Esloveno Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Slovenian Language Meta-Package for LibreOffice</gu>
    <he_IL>Slovenian Language Meta-Package for LibreOffice</he_IL>
-   <hi>Slovenian Language Meta-Package for LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस हेतु स्लोवेनियाई भाषा मेटा-पैकेज</hi>
    <hr>Slovenian Language Meta-Package for LibreOffice</hr>
    <hu>Slovenian Language Meta-Package for LibreOffice</hu>
    <id>Slovenian Language Meta-Package for LibreOffice</id>
@@ -41,6 +42,7 @@ Slovenian_LO_full
    <ja>LibreOffice用のスロベニア語メタパッケージ</ja>
    <kk>Slovenian Language Meta-Package for LibreOffice</kk>
    <ko>Slovenian Language Meta-Package for LibreOffice</ko>
+   <ku>Slovenian Language Meta-Package for LibreOffice</ku>
    <lt>Slovenian Language Meta-Package for LibreOffice</lt>
    <mk>Slovenian Language Meta-Package for LibreOffice</mk>
    <mr>Slovenian Language Meta-Package for LibreOffice</mr>
@@ -48,6 +50,7 @@ Slovenian_LO_full
    <nb>Slovensk språkpakke for LibreOffice</nb>
    <nl_BE>Slovenian Language Meta-Package for LibreOffice</nl_BE>
    <nl>Sloveens Taal Meta-Pakket voor LibreOffice</nl>
+   <or>Slovenian Language Meta-Package for LibreOffice</or>
    <pl>Słoweński meta-pakiet językowy dla LibreOffice</pl>
    <pt_BR>Esloveno Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Esloveno Meta-Pacote de Idioma para LibreOffice</pt>
@@ -55,7 +58,8 @@ Slovenian_LO_full
    <ru>Slovenian Language Meta-Package for LibreOffice</ru>
    <sk>Slovenian Language Meta-Package for LibreOffice</sk>
    <sl>Slovenski jezikovni meta-paket za LibreOffice</sl>
-   <sq>Slovenian Language Meta-Package for LibreOffice</sq>
+   <so>Slovenian Language Meta-Package for LibreOffice</so>
+   <sq>Meta-Paketë gjuhësore për LibreOffice-in në sllovenisht</sq>
    <sr>Slovenian Language Meta-Package for LibreOffice</sr>
    <sv>Sloveniskt Språk Meta-Paket för LibreOffice</sv>
    <th>Meta-Package ภาษา Slovenian สำหรับ LibreOffice</th>
@@ -74,12 +78,12 @@ all
 <screenshot>none</screenshot>
 
 <preinstall>
-echo "deb http://deb.debian.org/debian buster-backports main contrib non-free">/etc/apt/sources.list.d/pitemp.list
+echo "deb http://deb.debian.org/debian bullseye-backports main contrib non-free">/etc/apt/sources.list.d/pitemp.list
 apt-get update
 </preinstall>
 
 <install_package_names>
--t buster-backports libreoffice-base-core
+-t bullseye-backports libreoffice-base-core
 libreoffice-calc
 libreoffice-draw
 libreoffice-impress
@@ -88,6 +92,7 @@ libreoffice-writer
 libreoffice-base
 libreoffice-gtk3
 libreoffice-l10n-sl
+libreoffice-java-common
 </install_package_names>
 
 <postinstall>
@@ -103,6 +108,7 @@ libreoffice-impress
 libreoffice-math
 libreoffice-writer
 libreoffice-base
+libreoffice-java-common
 libreoffice-gtk3
 libreoffice-l10n-sl
 </uninstall_package_names>
