@@ -15,13 +15,13 @@ fvwm_crystal
    <be>fvwm-crystal window manager</be>
    <bg>fvwm-crystal window manager</bg>
    <bn>fvwm-crystal window manager</bn>
-   <ca>fvwm-crystal window manager</ca>
+   <ca>Gestor de finestres fvwm-crystal</ca>
    <cs>fvwm-crystal window manager</cs>
    <da>fvwm-crystal window manager</da>
    <de>transparenter “Chrystal” Stil für die Fensterverwaltung “FVWM”</de>
    <el>διαχειριστής παραθύρων fvwm-crystal</el>
    <en>fvwm-crystal window manager</en>
-   <es_ES>fvwm-crystal window manager</es_ES>
+   <es_ES>Gestor de ventanas fvwm-crystal</es_ES>
    <es>gestor de ventanas fvwm-crystal</es>
    <et>fvwm-crystal window manager</et>
    <eu>fvwm-crystal window manager</eu>
@@ -31,8 +31,9 @@ fvwm_crystal
    <fr_BE>fvwm-crystal gestionnaire de fenêtres</fr_BE>
    <fr>fvwm-crystal gestionnaire de fenêtres</fr>
    <gl_ES>fvwm-crystal window manager</gl_ES>
+   <gu>fvwm-crystal window manager</gu>
    <he_IL>fvwm-crystal window manager</he_IL>
-   <hi>fvwm-crystal window manager</hi>
+   <hi>एफवी-डब्लूएम क्रिस्टल सरल विंडो प्रबंधक</hi>
    <hr>fvwm-crystal window manager</hr>
    <hu>fvwm-crystal window manager</hu>
    <id>fvwm-crystal window manager</id>
@@ -41,25 +42,28 @@ fvwm_crystal
    <ja>FVWM-Crystal ウィンドウマネージャ</ja>
    <kk>fvwm-crystal window manager</kk>
    <ko>fvwm-crystal window manager</ko>
+   <ku>fvwm-crystal window manager</ku>
    <lt>fvwm-crystal window manager</lt>
    <mk>fvwm-crystal window manager</mk>
    <mr>fvwm-crystal window manager</mr>
    <nb_NO>fvwm-crystal window manager</nb_NO>
    <nb>Vindusbehandleren fvwm-crystal</nb>
    <nl_BE>fvwm-crystal window manager</nl_BE>
-   <nl>fvwm-crystal window manager</nl>
+   <nl>fvwm-crystal venster beheerder</nl>
+   <or>fvwm-crystal window manager</or>
    <pl>fvwm-crystal window manager</pl>
-   <pt_BR>fvwm-crystal gerenciador de janela</pt_BR>
+   <pt_BR>fvwm-crystal gerenciador de janelas</pt_BR>
    <pt>Gestor de janelas fvwm-crystal</pt>
    <ro>fvwm-crystal window manager</ro>
    <ru>fvwm-crystal window manager</ru>
    <sk>fvwm-crystal window manager</sk>
-   <sl>fvwm-crystal window manager</sl>
-   <sq>fvwm-crystal window manager</sq>
+   <sl>fvwm-crystal okenski upravljalnik</sl>
+   <so>fvwm-crystal window manager</so>
+   <sq>Përgjegjësi fvwm-crystal i dritareve</sq>
    <sr>fvwm-crystal window manager</sr>
    <sv>fvwm-crystal fönsterhanterare</sv>
    <th>fvwm-crystal window manager</th>
-   <tr>fvwm-crystal window manager</tr>
+   <tr>fvwm-crystal pencere yöneticisi</tr>
    <uk>fvwm-crystal window manager</uk>
    <vi>fvwm-crystal window manager</vi>
    <zh_CN>fvwm-crystal window manager</zh_CN>
